//%attributes = {"shared":true}
C_TEXT:C284($1; $filePath)  // @param: The full (absolute) pathname to the image file. @optional
C_OBJECT:C1216($2; $options)  // @param: Options. @optional
C_TEXT:C284($0; $imgDocRef)  // @param: The image document reference.

// @desc: Create an image document instance referencing an existing file.

// @doc: Create an image document instance referencing an existing file. The image document
// reference is returned in ``imgDocRef``.
//
// If the method call fails for some reason, an empty string is returned and the
// Q2Pix :ref:`error info <ImgErr_GetInfo>` is set accordingly.
//
// Parameter ``filePath`` is the full (absolute) pathname to the image file. The pathname
// may be in either POSIX (recommended) or System format.
//
// If ``filePath`` is omitted or set to an empty string, the standard file dialog that
// allows selection of any supported format is presented to the user. If the user selects
// a file, the method tries to open that file. If the user cancels the dialog,
// the error domain and code
// are set to ``"Q2Pix"`` and ``kQ2PixErrIntr`` respectively and the method returns an empty string.
//
// .. note:: The full pathname of the file selected by the user can be retrieved after a successful
//           completion of this method with a call to :cc4d:cmethod:`ImgDoc_GetFilePath`.
//
// The optional ``options`` object parameter may contain the following properties:
//
// .. list-table::
//    :widths: 30 70
//    :header-rows: 1
//
//    * - Property name
//      - Description
//    * - "Format"
//      - The option's value is the format identifier (a string) of the
//        specified image document. This option does not restrict the reading of the image to the
//        specified format, but rather acts as a 'hint' to the plug-in and underlying OS imaging
//        libraries.
//    * - "Password"
//      - The option's value is the password (a string) for a protected PDF document.
//    * - "AllowUserInteraction"
//      - The option's value is a boolean denoting whether user interaction is allowed.
//        Default value is ``True``.
//
// If the specified file or the one selected by the user is a locked PDF document and opening
// it fails with an authorization error (``"Q2Pix"``/``kQ2PixErrAuth``), a password entry dialog
// is presented to the user. If the user enters the correct password, the PDF document is opened
// and the document reference is returned. If the user cancels the dialog, the Q2Pix error info
// is set to ``"Q2Pix"``/``kQ2PixErrAuth`` and the method returns an empty string. If the user enters
// an invalid password, the method keeps running the password request dialog until the user either
// enters the correct dialog, or cancels.
//
// The ``AllowUserInteraction`` property defaults to ``True``, which allows this command to
// present the file selection or PDF password dialog, if necessary. When calling this
// method in a batch or unattended process, you may consider setting this to ``False`` so as the
// process is not halted by dialogs waiting for user input.
//
// .. note:: This method is a wrapper for the :cc4d:xmethod:`ImgDoc_CreateWithFile_JSN` plug-in method.
//           In addition to converting the ``options`` object to JSON for passing to the plug-in,
//           it offers some extra functionality in the form of the file selection and PDF password
//           dialogs.
//

If (Count parameters:C259>0)
	$filePath:=$1
End if 

If (Count parameters:C259>1)
	$options:=$2
End if 

C_TEXT:C284($optionsJSON)
If (OB Is defined:C1231($options))
	$optionsJSON:=JSON Stringify:C1217($options)
End if 

C_BOOLEAN:C305($allowInteraction)
$allowInteraction:=Choose:C955($options["AllowUserInteraction"]#Null:C1517; \
Bool:C1537($options["AllowUserInteraction"]); True:C214)

If (($filePath="") & $allowInteraction)
	$filePath:=ImgDlog_PromptOpenFile
	If ($filePath="")
		
		C_OBJECT:C1216($errInfo)
		OB SET:C1220($errInfo; "Domain"; "Q2Pix"; "Code"; kQ2PixErrIntr; \
			"Method"; Current method name:C684)
		ImgErr_SetInfo($errInfo)
		
	End if 
End if 

If ($filePath#"")
	
	$imgDocRef:=ImgDoc_CreateWithFile_JSN:P11667:5($filePath; $optionsJSON)
	If (($imgDocRef="") & $allowInteraction)
		
		C_BOOLEAN:C305($break)
		$break:=False:C215
		
		While (Not:C34($break)\
			 & ($imgDocRef="")\
			 & (ImgErr_GetDomain="Q2Pix") & (ImgErr_GetCode=kQ2PixErrAuth))
			C_TEXT:C284($password)
			$password:=ImgDlog_RequestPDFPassword($filePath)
			If ($password#"")
				C_OBJECT:C1216($localOptions)
				If (OB Is defined:C1231($options))
					$localOptions:=OB Copy:C1225($options)
				End if 
				OB SET:C1220($localOptions; "Password"; $password)
				$optionsJSON:=JSON Stringify:C1217($localOptions)
				$imgDocRef:=ImgDoc_CreateWithFile_JSN:P11667:5($filePath; $optionsJSON)
			Else 
				$break:=True:C214
			End if 
		End while 
		
	End if 
	
End if 

$0:=$imgDocRef
